@@ -4,7 +4,7 @@ from typing import List
 from functools import reduce
 from datetime import datetime
 from hestia_earth.utils.api import download_hestia
-from hestia_earth.utils.tools import list_average, safe_parse_date
+from hestia_earth.utils.tools import list_average, safe_parse_date, list_sum
 
 
 def _next_error(values: list): return next((x for x in values if x is not True), True)
@@ -117,10 +117,13 @@ def _value_average(node: dict, default=0, key='value'):
         return default
 
 
+def _download_linked_node(node: dict):
+    data = download_hestia(node.get('@id'), node.get('@type')) if node.get('@id') and node.get('@type') else None
+    return data if (data or {}).get('@id') == node.get('@id') else None
+
+
 def _find_linked_node(node_map: dict, node: dict):
-    return node_map.get(node.get('type'), {}).get(node.get('id')) or (
-        download_hestia(node.get('@id'), node.get('@type')) if node.get('@id') and node.get('@type') else node
-    )
+    return node_map.get(node.get('type'), {}).get(node.get('id')) or _download_linked_node(node)
 
 
 def _is_before_today(date: str): return safe_parse_date(date).date() <= datetime.now().date()
@@ -132,6 +135,28 @@ def _node_year(node: dict):
     return date.year if date else None
 
 
+def _model_value_from_list(results: list, default_value: float):
+    return results[0].get('value', [default_value]) if len(results) > 0 else default_value
+
+
+def _model_value(result, default_value=0):
+    return default_value if result is None else (
+        _model_value_from_list(result, default_value) if isinstance(result, list) else (
+            result.get('value', [default_value]) if isinstance(result, dict) else default_value
+        )
+    )
+
+
+def _value_from_model(result):
+    value = _model_value(result)
+    try:
+        # fix numpy.float64
+        # TODO: find a better way to handle this
+        return list_sum(value, float(value))
+    except Exception:
+        return list_sum(value, value)
+
+
 def _import_model(name: str):
     return importlib.import_module(f"hestia_earth.models.{name}").run
 
