@@ -19,7 +19,9 @@ VALIDATE_TYPE = {
     SchemaType.SITE.value: lambda n, nodes: validate_site(n, nodes)
 }
 SKIP_VALIDATE_DUPLICATES = [
-    SchemaType.ACTOR.value
+    SchemaType.ACTOR.value,
+    SchemaType.IMPACTASSESSMENT.value,
+    SchemaType.TERM.value
 ]
 
 
