@@ -184,7 +184,6 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         The list of errors for the `Cycle`, which can be empty if no errors detected.
     """
     site = _find_linked_node(node_map, cycle.get('site', {}))
-    cycle = {**cycle, 'site': site}
     return flatten([
         validate_cycle_dates(cycle),
         validate_date_lt_today(cycle, 'startDate'),
@@ -207,7 +206,7 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_list_date_lt_today(cycle, 'emissions', ['startDate', 'endDate']),
         validate_properties_default_value(cycle, 'emissions'),
         validate_properties_valueType(cycle, 'emissions'),
-        validate_linked_terms(cycle, 'emissions', 'inputs', 'inputs'),
+        validate_linked_terms(cycle, 'emissions', 'inputs', 'inputs', True),
         validate_linked_terms(cycle, 'emissions', 'transformation', 'transformations', True),
     ] if len(cycle.get('emissions', [])) > 0 else []) + flatten([
         validate_list_dates(cycle, 'inputs'),
@@ -254,7 +253,7 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_list_duplicate_values(cycle, 'practices', 'term.termType', TermTermType.EXCRETAMANAGEMENT.value),
         validate_excretaManagement(cycle, cycle.get('practices')),
         validate_no_tillage(cycle.get('practices')),
-        validate_tillage_site_type(cycle.get('practices'), site),
+        validate_tillage_site_type(cycle.get('practices'), site) if site else True,
         validate_tillage_values(cycle.get('practices'))
     ] if len(cycle.get('practices', [])) > 0 else []) + flatten([
         validate_functionalUnit(cycle, site)
