@@ -3,7 +3,7 @@ from hestia_earth.utils.lookup import download_lookup, get_table_value, column_n
 from hestia_earth.utils.tools import list_sum, non_empty_list, safe_parse_float, flatten
 
 from hestia_earth.validation.utils import _filter_list_errors, _value_average, _node_year
-from hestia_earth.validation.gee import fetch_data
+from hestia_earth.validation.utils import _value_from_model
 from .shared import need_validate_coordinates, value_difference
 
 
@@ -11,21 +11,17 @@ SOIL_TEXTURE_IDS = ['sandContent', 'siltContent', 'clayContent']
 
 
 def _rainfallAnnual(site: dict, measurement: dict):
+    from hestia_earth.models.spatial.rainfallAnnual import _run
     year = _node_year(measurement)
-    value = fetch_data(collection='ECMWF/ERA5/MONTHLY',
-                       ee_type='raster_by_period',
-                       band_name='total_precipitation',
-                       reducer='sum',
-                       reducer_regions='mean',
-                       year=str(year),
-                       latitude=site.get('latitude'),
-                       longitude=site.get('longitude')
-                       ).get('mean', None) if need_validate_coordinates(site) and year else None
-    return value * 1000 if value else None
+    result = _run(site, year) if year and need_validate_coordinates(site) else None
+    return result
 
 
 MEASUREMENTS_MODELS = {
-    'rainfallAnnual': _rainfallAnnual
+    'rainfallAnnual': [
+        'spatial',
+        _rainfallAnnual
+    ]
 }
 
 
@@ -189,7 +185,9 @@ def validate_with_models(site: dict, list_key: str):
         term_id = blank_node.get('term', {}).get('@id')
         value = blank_node.get('value', [0])
         value = list_sum(value, value)
-        expected_value = MEASUREMENTS_MODELS[term_id](site, blank_node) if term_id in MEASUREMENTS_MODELS else value
+        model, model_run = MEASUREMENTS_MODELS.get(term_id, [None, None])
+        expected_node = model_run(site, blank_node) if model else {}
+        expected_value = _value_from_model(expected_node) if expected_node else value
         delta = value_difference(value, expected_value) if expected_value else 0
         data_path = '' if blank_node.get('value') is None else '.value'
         return delta < threshold or {
@@ -198,6 +196,7 @@ def validate_with_models(site: dict, list_key: str):
             'message': 'the measurement provided might be in error',
             'params': {
                 'term': blank_node.get('term', {}),
+                'model': expected_node.get('methodModel', {}),
                 'current': value,
                 'expected': expected_value,
                 'delta': delta * 100,
