@@ -6,7 +6,7 @@ from hestia_earth.validation.validators.property import validate_valueType, vali
 
 def test_validate_valueType_valid():
     # no properties should be valid
-    assert validate_valueType({}, 'products')
+    assert validate_valueType({}, 'products') is True
 
     with open(f"{fixtures_path}/property/valueType/valid.json") as f:
         data = json.load(f)
