@@ -327,7 +327,13 @@ def test_validate_area_invalid():
     assert validate_area(node) == {
         'level': 'error',
         'dataPath': '.area',
-        'message': 'must be equal to boundary (~13.8)'
+        'message': 'must be equal to boundary (~13.8)',
+        'params': {
+            'current': 4.5,
+            'expected': 13.8,
+            'delta': 67.39,
+            'threshold': 0.05
+        }
     }
 
 
